OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nu se poate scrie în folderul \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Aceasta se poate rezolva de obicei  dând acces în scriere serverului în directorul configurației.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Dar, dacă preferați să păstrați config.php doar în citire, setați opțiunea \"config_is_read_only\" ca true.",
    "See %s" : "Vezi %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplicația %1$s nu este prezentă sau are o versiune incompatibilă cu acest server. Verificați directorul aplicațiilor.",
    "Sample configuration detected" : "A fost detectată o configurație exemplu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S-a detectat copierea configurației exemplu. Acest lucru poate duce la oprirea instanței tale și nu este suportat. Te rugăm să citești documentația înainte de a face modificări în fișierul config.php",
    "The page could not be found on the server." : "Pagina nu a fost găsită.",
    "%s email verification" : "%s verificare email",
    "Email verification" : "Verificare email",
    "Click the following button to confirm your email." : "Apăsați butonul următor pentru confirmare email.",
    "Click the following link to confirm your email." : "Click pe linkul următor pentru confirmare email.",
    "Confirm your email" : "Confirmați emailul",
    "Other activities" : "Alte activități",
    "%1$s and %2$s" : "%1$s și %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s și %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s și %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s și %5$s",
    "Enterprise bundle" : "Pachetul enterprise",
    "Groupware bundle" : "Pachetul Groupware",
    "Hub bundle" : "Pachetul central",
    "Social sharing bundle" : "Pachetul de partajare",
    "PHP %s or higher is required." : "Versiunea PHP %s sau mai mare este necesară.",
    "PHP with a version lower than %s is required." : "Este necesară o versiune PHP mai mică decât %s",
    "%sbit or higher PHP required." : "Este necesar PHP %sbit sau mai mare.",
    "The following architectures are supported: %s" : "Sunt suportate următoarele arhitecturi: %s",
    "The following databases are supported: %s" : "Sunt suportate următoarele baze de date: %s",
    "The command line tool %s could not be found" : "Unealta în linie de comandă %s nu a fost găsită",
    "The library %s is not available." : "Biblioteca %s nu este disponibilă.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Biblioteca %1$s cu o versiune superioară %2$s este necesară - versiunea disponibilă %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Biblioteca %1$s cu o versiune inferioară %2$s este necesară - versiunea disponibilă %3$s.",
    "The following platforms are supported: %s" : "Sunt suportate următoarele platforme: %s",
    "Server version %s or higher is required." : "Este necesară versiunea %s a serverului sau superioară.",
    "Server version %s or lower is required." : "Este necesară versiunea %s a serverului, sau inferioară.",
    "Wiping of device %s has started" : "A început curățarea dispozitivului %s ",
    "Wiping of device »%s« has started" : "A început curățarea dispozitivului  »%s« ",
    "»%s« started remote wipe" : "»%s« a pornit curățarea la distanță",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Dispozitivul sau aplicația »%s« a inițiat procesul de ștergere la distanță. Veți primi un alt mail când procesul se va finaliza",
    "Wiping of device %s has finished" : "Curățarea dispozitivului %s s-a finalizat",
    "Wiping of device »%s« has finished" : "Curățarea dispozitivului »%s« s-a finalizat",
    "»%s« finished remote wipe" : "»%s« a finalizat curățarea la distanță",
    "Device or application »%s« has finished the remote wipe process." : "Dispozitivul sau aplicația »%s« a finalizat procesul de curățare la distanță.",
    "Remote wipe started" : "Curățarea la distanță a fost inițiată",
    "A remote wipe was started on device %s" : "A fost inițiată o curățare la distanță a dispozitivului %s",
    "Remote wipe finished" : "Curățarea la distanță a fost finalizată",
    "The remote wipe on %s has finished" : "Curățarea la distanță a  %s a fost finalizată",
    "Authentication" : "Autentificare",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "Avatar image is not square" : "Imaginea de avatar nu este pătrată",
    "Files" : "Fișiere",
    "View profile" : "Vezi profilul",
    "Local time: %s" : "Timp local: %s",
    "today" : "astăzi",
    "tomorrow" : "mâine",
    "yesterday" : "ieri",
    "_in %n day_::_in %n days_" : ["în %n zi","în %n zile","în %n zile"],
    "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
    "next month" : "luna viitoare",
    "last month" : "ultima lună",
    "_in %n month_::_in %n months_" : ["în %n lună","în %n luni","în %n luni"],
    "_%n month ago_::_%n months ago_" : ["%n lună în urmă","%n luni în urmă","%n luni în urmă"],
    "next year" : "anul viitor",
    "last year" : "ultimul an",
    "_in %n year_::_in %n years_" : ["în %n an","în %n ani","în %n ani"],
    "_%n year ago_::_%n years ago_" : ["%n an în urmă","%n ani în urmâ","%n ani în urmâ"],
    "_in %n hour_::_in %n hours_" : ["în %n oră","în %n ore","în %n ore"],
    "_%n hour ago_::_%n hours ago_" : ["%n oră în urmă","%n ore în urmă","%n ore în urmă"],
    "_in %n minute_::_in %n minutes_" : ["în %n minut","în %n minute","în %n minute"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut în urmă","%n minute în urmă","%n minute în urmă"],
    "in a few seconds" : "în câteva secunde",
    "seconds ago" : "secunde în urmă",
    "Empty file" : "Fișier gol",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulul cu ID: %s nu există. Activați-l din setările aplicației sau contactați administratorul.",
    "Dot files are not allowed" : "Fișierele care încep cu caracterul punct nu sunt permise",
    "File already exists" : "Fișierul există deja",
    "Invalid path" : "Cale invalidă",
    "Failed to create file from template" : "Eroare la crearea fișierului pe baza șablonului",
    "Templates" : "Șabloane",
    "Filename contains at least one invalid character" : "Numele fișierului conține cel puțin un caracter invalid",
    "Empty filename is not allowed" : "Nu este permis fișier fără nume",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplicația \"%s\" nu poate fi instalată deoarece fișierul appinfo nu poate fi citit.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplicația \"%s\" nu poate fi instalată deoarece nu este compatibilă cu versiunea serverului.",
    "__language_name__" : "Română",
    "This is an automatically sent email, please do not reply." : "Acesta este un email automat, nu răspundeți.",
    "Appearance and accessibility" : "Aspect și accesibilitate",
    "Apps" : "Aplicații",
    "Personal settings" : "Setări personale",
    "Administration settings" : "Setări de administrare",
    "Settings" : "Setări",
    "Log out" : "Ieșire",
    "Accounts" : "Conturi",
    "Email" : "E-mail",
    "View %s on the fediverse" : "Vedeți %s pe fediverse",
    "Phone" : "Telefon",
    "Call %s" : "Apel %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Vedeți %s pe X",
    "Website" : "Site web",
    "Visit %s" : "Vizitați %s",
    "Address" : "Adresă",
    "Profile picture" : "Imagine de profil",
    "About" : "Despre",
    "Display name" : "Nume afișat",
    "Headline" : "Titlu",
    "Organisation" : "Organizație",
    "Role" : "Rol",
    "Additional settings" : "Setări adiționale",
    "Enter the database name for %s" : "Introduceți numele bazei de date pentru %s",
    "You cannot use dots in the database name %s" : "Nu puteți folosi puncte în numele bazei de date %s",
    "You need to enter details of an existing account." : "Sunt necesare detaliile unui cont existent.",
    "Oracle connection could not be established" : "Conexiunea Oracle nu a putut fi stabilită",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nu este suportat și %s nu va funcționa corect pe această platformă. Continuați pe propriul risc! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Pentru cele mai bune rezultate, ia în calcul folosirea unui server care rulează un sistem de operare GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Se pare că această instanță a %s rulează o versiune 32-bit a PHP și open_basedir a fost configurat în php.ini. Aceasta va conduce la probleme cu fișierele mai mari de 4 GB și nu este deloc recomandată.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Eliminați setarea open_basedir din php.ini utilizați versiunea 64-bit a PHP.",
    "Set an admin password." : "Setează o parolă de administrator.",
    "Cannot create or write into the data directory %s" : "Nu se poate crea sau scrie în dosarul pentru date %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend-ul de partajare %s trebuie să implementeze interfața OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend-ul de partajare %s nu există",
    "Sharing backend for %s not found" : "Backend-ul de partajare pentru %s nu a fost găsit",
    "%1$s via %2$s" : "%1$sprin %2$s",
    "Unknown share type" : "Tip necunoscut de partajare",
    "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
    "Cannot increase permissions of %s" : "Nu se pot extinde permisiunile pentru %s",
    "Files cannot be shared with delete permissions" : "Fișierele nu pot fi partajate cu permisiunea de ștergere",
    "Files cannot be shared with create permissions" : "Fișierele nu pot fi partajate cu permisiunea de creare",
    "Expiration date is in the past" : "Data expirării este în trecut",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Data expirării nu poate fi mai mult de %n zi în viitor","Data expirării nu poate fi mai mult de %n zile în viitor","Data expirării nu poate fi mai mult de %n zile în viitor"],
    "Sharing is only allowed with group members" : "Partajarea este permisă doar cu membrii grupului",
    "The requested share does not exist anymore" : "Partajarea solicitată nu mai există",
    "The requested share comes from a disabled user" : "Partajarea solicitată provine de la un utilizator dezactivat",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Utilizatorul nu a fost creat deoarece s-a atins limita acestui număr. Verificați notificările pentru a afla mai mult.",
    "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
    "Sunday" : "Duminică",
    "Monday" : "Luni",
    "Tuesday" : "Marți",
    "Wednesday" : "Miercuri",
    "Thursday" : "Joi",
    "Friday" : "Vineri",
    "Saturday" : "Sâmbătă",
    "Sun." : "Dum.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Joi",
    "Fri." : "Vin.",
    "Sat." : "Sâm.",
    "Su" : "Du",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Jo",
    "Fr" : "Vi",
    "Sa" : "Sâ",
    "January" : "Ianuarie",
    "February" : "Februarie",
    "March" : "Martie",
    "April" : "Aprilie",
    "May" : "Mai",
    "June" : "Iunie",
    "July" : "Iulie",
    "August" : "August",
    "September" : "Septembrie",
    "October" : "Octombrie",
    "November" : "Noiembrie",
    "December" : "Decembrie",
    "Jan." : "Ian.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Iun.",
    "Jul." : "Iul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Noi.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "Login canceled by app" : "Autentificare anulată de aplicație",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplicația \"%1$s\" nu poate fi instalată deoarece următoarele dependențe nu sunt satisfăcute: %2$s",
    "a safe home for all your data" : "o casă sigură pentru toate datele dumneavoastră",
    "Application is not enabled" : "Aplicația nu este activată",
    "Authentication error" : "Eroare la autentificare",
    "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nu sunt instalate drivere pentru baze de date (sqlite, mysql sau postgresql).",
    "Cannot write into \"config\" directory." : "Nu se poate scrie în directorul \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Aceasta se poate remedia de obicei prin asigurarea accesului în scriere serverului la directorul configurației. Vedeți  %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Sau, dacă preferați să păstrați config.php doar în citire, setați opțiunea \"config_is_read_only\" ca true. Vedeți %s",
    "Cannot write into \"apps\" directory." : "Nu se poate scrie în directorul \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Aceasta se poate remedia permițând serverului web să acceseze directorul aplicațiilor sau dezactivând App Store în fișierul de configurație.",
    "Cannot create \"data\" directory." : "Nu se poate crea directorul \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Aceasta se remediază de obicei permițând serverului web accesul în scriere în directorul rădăcină. Vedeți %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Permisiunile se rezolvă de obicei dând serverului web acces în scriere în directorul rădăcină. Vedeți  %s.",
    "Your data directory is not writable." : "Directorul data nu are acces în scriere.",
    "Setting locale to %s failed." : "Setarea localizării la %s a eșuat.",
    "Please install one of these locales on your system and restart your web server." : "Instalați una din aceste localizări pe sistem și reporniți serverul web.",
    "PHP module %s not installed." : "Modulul PHP %s nu este instalat.",
    "Please ask your server administrator to install the module." : "Solicitați administratorului să instaleze modulul.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Setarea PHP \"%s\" nu este setată la \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustând aceste setări în php.ini va permite ca Nextcloud să funcționeze din nou",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> este setată la <code>%s</code> în locul valorii așteptate <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pentru a remedia problema setați <code>mbstring.func_overload</code> la <code>0</code> în php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP este aparent configurat pentru a elimina blocurile de documente inline. Acest lucru va face mai multe aplicații de bază inaccesibile.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Aceasta se datorează probabil unui accelerator/cache precum Zend OPcache sau eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
    "Please ask your server administrator to restart the web server." : "Solicitați administratorului să restarteze serverul web.",
    "The required %s config variable is not configured in the config.php file." : "Variabila de configurație %s nu este prezentă în config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Solicitați administratorului să verifice configurația Nextcloud. ",
    "Your data directory must be an absolute path." : "Directorul de date trebuie să fie o cale absolută.",
    "Check the value of \"datadirectory\" in your configuration." : "Verificați valoarea \"datadirectory\" în configurație.",
    "Your data directory is invalid." : "Directorul de date este invalid.",
    "Action \"%s\" not supported or implemented." : "Acțiunea \"%s\" nu este suportată sau implementată.",
    "Authentication failed, wrong token or provider ID given" : "Autentificare eșuată, token greșit sau ID provider eronat",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametri lipsă pentru îndeplinirea solicitării. Parametrii lipsă: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" deja folosit de providerul cloud federation \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Providerul Cloud Federation cu ID: \"%s\" nu există.",
    "Could not obtain lock type %d on \"%s\"." : "Nu se poate aplica tipul %d de blocare pe \"%s\".",
    "Storage unauthorized. %s" : "Spațiu de stocare neautorizat. %s",
    "Storage incomplete configuration. %s" : "Configurație incompletă a spațiului de stocare. %s",
    "Storage connection error. %s" : "Eroare conexiune cu spațiul de stocare. %s",
    "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
    "Storage connection timeout. %s" : "Timeout la conexiunea cu spațiul de stocare. %s",
    "Generates a possible headline for a text." : "Generează un posibil titlu pentru text",
    "Text" : "Text",
    "Summarize" : "Rezumă",
    "Summary" : "Rezumat",
    "Extract topics" : "Extrage subiecte",
    "Translate" : "Tradu",
    "Free prompt" : "Eliberează prompt-ul",
    "Runs an arbitrary prompt through the language model." : "Rulează un prompt arbitrar prin modelul lingvistic.",
    "Generate headline" : "Generează titlu",
    "Summarizes text by reducing its length without losing key information." : "Rezumă textul prin reducerea lungimii acestuia, fără a pierde informațiile cheie.",
    "Extracts topics from a text and outputs them separated by commas." : "Extrage subiecte din text și le furnizează separate prin virgulă.",
    "Education Edition" : "Ediția pentru educație",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Utilizatorul trebuie să fie administrator, sub-administrator sau să aibă permisiunea specială de a accesa această setare",
    "Logged in user must be an admin or sub admin" : "Utilizatorul trebuie să fie administrator sau sub-administrator",
    "Logged in user must be an admin" : "Utilizatorul trebuie să fie administrator",
    "File name is a reserved word" : "Numele fișierului este un cuvânt rezervat",
    "File name contains at least one invalid character" : "Numele fișierului conține cel puțin un caracter invalid",
    "File name is too long" : "Numele fișierului este prea lung",
    "Help" : "Ajutor",
    "Users" : "Utilizatori",
    "Unknown user" : "Utilizator necunoscut",
    "Enter the database username and name for %s" : "Introduceți utilizatorul pentru baza de date și numele pentru %s",
    "Enter the database username for %s" : "Introduceți utilizatorul pentru %s",
    "MySQL username and/or password not valid" : "Utilizatorul sau/și parola MySQL invalide",
    "Oracle username and/or password not valid" : "Numele de utilizator sau / și parola Oracle nu sunt valide",
    "PostgreSQL username and/or password not valid" : "Nume utilizator și/sau parolă PostgreSQL greșită",
    "Set an admin username." : "Setează un nume de administrator.",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s a partajat »%2$s« cu tine și vrea să adauge:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s a partajat »%2$s« cu tine și vrea să adauge",
    "»%s« added a note to a file shared with you" : "%s« a adaugat un comentariu la un fișier partajat cu tine",
    "Open »%s«" : "Deschide »%s«",
    "Sharing %s failed, because this item is already shared with user %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu utilizatorul %s",
    "%1$s shared »%2$s« with you" : "%1$s a partajat »%2$s« cu tine",
    "%1$s shared »%2$s« with you." : "%1$sa partajat »%2$s« cu tine.",
    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
    "The username is already being used" : "Numele de utilizator este deja folosit",
    "Could not create user" : "Nu s-a putut crea utilizatorul",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Doar următoarele caractere sunt permise în numele de utilizatori: \"a-z\", \"A-Z\", \"0-9\", spații și \"_.@-'\"",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "Username contains whitespace at the beginning or at the end" : "Utilizatorul contine spațiu liber la început sau la sfârșit",
    "Username must not consist of dots only" : "Numele utilizatorului nu poate conține numai puncte",
    "Username is invalid because files already exist for this user" : "Numele utilizatorului este invalid deoarece există deja fișiere pentru acesta",
    "User disabled" : "Utilizator dezactivat",
    "File is currently busy, please try again later" : "Fișierul este blocat momentan, încercați din nou mai târziu",
    "Cannot download file" : "Fișierul nu se poate descărca",
    "Your data directory is readable by other users." : "Directorul de date este accesibil altor utilizatori.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Setați permisiunea 0770 astfel ca directorul să nu poată fi parcurs de alți utilizatori.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asigurați-vă că fișierul \".ocdata\" există în rădăcina directorului de date."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
